import { jsx as _jsx } from "react/jsx-runtime";
import { render, cleanup } from "@testing-library/react";
import { AdvancedNumber } from "./index";
describe("AdvancedNumber", function () {
    afterEach(cleanup);
    describe("Base component", function () {
        test("Component structure with no decimal", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Component structure with decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              56\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
    });
    describe("Formatting", function () {
        test("Currency formatting", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56789, options: {
                    style: "currency",
                    currency: "USD",
                    currencyDisplay: "narrowSymbol",
                } }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              $\n            </span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              57\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Percent formatting", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 0.654321, options: {
                    style: "percent",
                    minimumFractionDigits: 2,
                } }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              65\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              43\n            </span>\n            <span>\n              %\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Localized formatting", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56789, locales: "fr", options: {
                    useGrouping: false,
                } }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1234\n            </span>\n            <span>\n              ,\n            </span>\n            <span>\n              568\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
    });
    describe("Diff Highlighting", function () {
        test("Positive difference on integer", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234, previousValue: 1222 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                34\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Positive difference on integer and decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1222.22 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                34\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                56\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Positive difference on decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1234.52 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              5\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                6\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Negative difference on integer", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234, previousValue: 1245 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                34\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Negative difference on integer and decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1244.56 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                34\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                56\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Positive difference on different length", function () {
            var component = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 989.22 }, void 0));
            expect(component.asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                1,234\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                56\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
            var component2 = render(_jsx(AdvancedNumber, { value: 1089.22, previousValue: 989.22 }, void 0));
            expect(component2.asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                1,089\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                22\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Negative difference on different length", function () {
            var component = render(_jsx(AdvancedNumber, { value: 989.22, previousValue: 1234.56 }, void 0));
            expect(component.asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                989\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                22\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
            var component2 = render(_jsx(AdvancedNumber, { value: 989.22, previousValue: 1089.22 }, void 0));
            expect(component2.asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                989\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                22\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Negative difference on decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1234.58 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              5\n              <span\n                style=\"color: rgb(244, 67, 54);\"\n              >\n                6\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Custom positive color on integer", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234, previousValue: 1222, positiveColor: "#03A9F4" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(3, 169, 244);\"\n              >\n                34\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Custom positive color on integer and decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1222.22, positiveColor: "#03A9F4" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(3, 169, 244);\"\n              >\n                34\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(3, 169, 244);\"\n              >\n                56\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Custom positive color on decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1234.52, positiveColor: "#03A9F4" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              5\n              <span\n                style=\"color: rgb(3, 169, 244);\"\n              >\n                6\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Custom negative color on integer", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234, previousValue: 1245, negativeColor: "#C238DA" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(194, 56, 218);\"\n              >\n                34\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Custom negative color on integer and decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1244.56, negativeColor: "#C238DA" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,2\n              <span\n                style=\"color: rgb(194, 56, 218);\"\n              >\n                34\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span\n                style=\"color: rgb(194, 56, 218);\"\n              >\n                56\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Custom negative color on decimals", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1234.58, negativeColor: "#C238DA" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              5\n              <span\n                style=\"color: rgb(194, 56, 218);\"\n              >\n                6\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test.todo("Check when options.notation !== 'standard'");
    });
    describe("Muted Decimals", function () {
        test("Feature enabled without required props", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, showMutedDecimals: true }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              56\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Feature enabled with maxDecimalDigits > significantDecimalDigits", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, showMutedDecimals: true, significantDecimalDigits: 2, maxDecimalDigits: 6 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              56\n              <span\n                style=\"opacity: 0.7;\"\n              >\n                0000\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Feature enabled with maxDecimalDigits === significantDecimalDigits", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, showMutedDecimals: true, significantDecimalDigits: 4, maxDecimalDigits: 4 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              5600\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Feature enabled with maxDecimalDigits <= significantDecimalDigits", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, showMutedDecimals: true, significantDecimalDigits: 4, maxDecimalDigits: 2 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              5600\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test.todo("significantDecimalDigits overrides both options.minimumFractionDigits and options.maximumFractionDigits");
        test("Feature is disabled if options.notation !== 'standard'", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, options: { notation: "compact" }, showMutedDecimals: true, significantDecimalDigits: 6, maxDecimalDigits: 6 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              234560\n            </span>\n            <span>\n              K\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test.todo("Check impact of minimumSignificantDigits and maximumSignificantDigits");
    });
    describe("Privacy mode", function () {
        test("The root span has style when feature is enabled", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, privacyMode: true }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span\n            style=\"color: transparent; text-shadow: 0 0 0.5em #7C7C7CD9;\"\n          >\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              56\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("The root span doesn't have style when feature is disabled", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              56\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("Overrides difference style", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, previousValue: 1222.22, privacyMode: true }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span\n            style=\"color: transparent; text-shadow: 0 0 0.5em #7C7C7CD9;\"\n          >\n            <span>\n              1,2\n              <span>\n                34\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              <span>\n                56\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("The privacy style has suctomm color", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, privacyMode: true, privacyShadowColor: "#03A9F4CC" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span\n            style=\"color: transparent; text-shadow: 0 0 0.5em #03A9F4CC;\"\n          >\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              56\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
    });
    describe("Small decimals", function () {
        test("The decimals span has style when feature is enabled", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56, smallDecimals: true }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span\n              style=\"font-size: 0.8em;\"\n            >\n              56\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("The decimals span dones't have style when feature is disabled", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span>\n            <span>\n              1,234\n            </span>\n            <span>\n              .\n            </span>\n            <span>\n              56\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
    });
    describe("Styling", function () {
        test("Style props is forwarded to root span", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234, style: { fontFamily: "monospace" } }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span\n            style=\"font-family: monospace;\"\n          >\n            <span>\n              1,234\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
        test("ClassName props is forwarded to root span", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234, className: "advanced-number" }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span\n            class=\"advanced-number\"\n          >\n            <span>\n              1,234\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
    });
    describe("All together", function () {
        test("All feature combined", function () {
            var asFragment = render(_jsx(AdvancedNumber, { value: 1234.56789, previousValue: 1099.01, options: {
                    style: "currency",
                    currency: "USD",
                    currencyDisplay: "narrowSymbol",
                }, style: { fontFamily: "monospace" }, smallDecimals: true, showMutedDecimals: true, significantDecimalDigits: 2, maxDecimalDigits: 6 }, void 0)).asFragment;
            expect(asFragment()).toMatchInlineSnapshot("\n        <DocumentFragment>\n          <span\n            style=\"font-family: monospace;\"\n          >\n            <span>\n              $\n            </span>\n            <span>\n              1,\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                234\n              </span>\n            </span>\n            <span>\n              .\n            </span>\n            <span\n              style=\"font-size: 0.8em;\"\n            >\n              <span\n                style=\"color: rgb(76, 175, 80);\"\n              >\n                57\n                <span\n                  style=\"opacity: 0.7;\"\n                >\n                  0000\n                </span>\n              </span>\n            </span>\n          </span>\n        </DocumentFragment>\n      ");
        });
    });
});
