var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { getFraction, getInteger, getPrefix, getSeparator, getSuffix, getMutedDigits, getDiffColor, getComparisonDiffIndex, extractSpanProps, } from "./utils";
describe("Utils", function () {
    var numberPartsFull = [
        { type: "literal", value: " " },
        { type: "currency", value: "USD" },
        { type: "literal", value: " " },
        { type: "minusSign", value: "-" },
        { type: "integer", value: "3" },
        { type: "group", value: "." },
        { type: "integer", value: "500" },
        { type: "decimal", value: "," },
        { type: "fraction", value: "00" },
        { type: "literal", value: " " },
        { type: "currency", value: "€" },
        { type: "literal", value: " " },
    ];
    var numberPartsEmpty = [];
    describe("getPrefix", function () {
        test("returns the prefix as a concatenated string", function () {
            expect(getPrefix(numberPartsFull)).toBe("USD -");
        });
        test("returns an empty string if no prefix part", function () {
            expect(getPrefix(numberPartsEmpty)).toBe("");
        });
    });
    describe("getInteger", function () {
        test("returns the integer parts as a concatenated string", function () {
            expect(getInteger(numberPartsFull)).toBe("3.500");
        });
        test("returns an empty string if no fraction part", function () {
            expect(getInteger(numberPartsEmpty)).toBe("");
        });
    });
    describe("getSeparator", function () {
        test("returns the separator", function () {
            expect(getSeparator(numberPartsFull)).toBe(",");
        });
        test("returns an empty string if no separator", function () {
            expect(getSeparator(numberPartsEmpty)).toBe("");
        });
    });
    describe("getFraction", function () {
        test("returns the fraction parts as a concatenated string", function () {
            expect(getFraction(numberPartsFull)).toBe("00");
        });
        test("returns an empty string if no fraction part", function () {
            expect(getFraction(numberPartsEmpty)).toBe("");
        });
    });
    describe("getSuffix", function () {
        test("returns the suffix as a concatenated string", function () {
            expect(getSuffix(numberPartsFull)).toBe(" €");
        });
        test("returns an empty string if no suffix part", function () {
            expect(getSuffix(numberPartsEmpty)).toBe("");
        });
    });
    describe("getComparisonDiffIndex", function () {
        test("returns the index of the difff", function () {
            expect(getComparisonDiffIndex("1234", "1234")).toEqual(4);
            expect(getComparisonDiffIndex("1234", "1233")).toEqual(3);
            expect(getComparisonDiffIndex("1233", "1234")).toEqual(3);
            expect(getComparisonDiffIndex("1234", "1224")).toEqual(2);
            expect(getComparisonDiffIndex("1224", "1234")).toEqual(2);
            expect(getComparisonDiffIndex("1134", "1234")).toEqual(1);
            expect(getComparisonDiffIndex("1234", "1134")).toEqual(1);
            expect(getComparisonDiffIndex("1224", "2345")).toEqual(0);
        });
        test("handles params of different length", function () {
            expect(getComparisonDiffIndex("123", "11234")).toEqual(0);
            expect(getComparisonDiffIndex("11234", "123")).toEqual(0);
        });
        test("handles empty string params", function () {
            expect(getComparisonDiffIndex("1234", "")).toEqual(0);
            expect(getComparisonDiffIndex("", "1234")).toEqual(0);
            expect(getComparisonDiffIndex("", "")).toEqual(0);
        });
    });
    describe("getMutedDigits", function () {
        test("returns n zeros when maxDigits > nbDigits", function () {
            expect(getMutedDigits(1, 2)).toBe("0");
            expect(getMutedDigits(1, 4)).toBe("000");
        });
        test("returns empty string maxDigits <= nbDigits", function () {
            expect(getMutedDigits(1, 1)).toBe("");
            expect(getMutedDigits(2, 1)).toBe("");
        });
    });
    describe("getDiffColor", function () {
        var positiveColor = "#111111";
        var negativeColor = "#222222";
        test("returns the positive color if value > previousValue", function () {
            expect(getDiffColor(positiveColor, negativeColor, 2, 1)).toBe(positiveColor);
        });
        test("returns the negative color if value < previousValue", function () {
            expect(getDiffColor(positiveColor, negativeColor, 1, 2)).toBe(negativeColor);
        });
        test("returns 'inherit' if value === previousValue", function () {
            expect(getDiffColor(positiveColor, negativeColor, 1, 1)).toBe("inherit");
        });
        test("returns 'inherit' if previousValue is undefined", function () {
            expect(getDiffColor(positiveColor, negativeColor, 1)).toBe("inherit");
        });
    });
    describe("extractSpanProps", function () {
        var spanProps = {
            style: {},
            className: "test",
        };
        var componentFullProps = {
            value: 1234.5,
            locales: "",
            maxDecimalDigits: 1,
            negativeColor: "",
            options: {},
            positiveColor: "",
            previousValue: 0.1,
            privacyMode: false,
            privacyShadowColor: "",
            showMutedDecimals: true,
            significantDecimalDigits: 1,
            smallDecimals: true,
        };
        var componentMinimalProps = {
            value: 1234.5,
        };
        var fullProps = __assign(__assign({}, componentFullProps), spanProps);
        var partialProps = __assign(__assign({}, componentMinimalProps), spanProps);
        var minimalProps = __assign({}, componentMinimalProps);
        test("returns an object not containing the component properties", function () {
            expect(extractSpanProps(fullProps)).toEqual(expect.not.objectContaining(componentFullProps));
            expect(extractSpanProps(partialProps)).toEqual(expect.not.objectContaining(componentMinimalProps));
            expect(extractSpanProps(minimalProps)).toEqual(expect.not.objectContaining(componentMinimalProps));
        });
        test("returns an object containing the span properties, if any", function () {
            expect(extractSpanProps(fullProps)).toEqual(expect.objectContaining(spanProps));
            expect(extractSpanProps(partialProps)).toEqual(expect.objectContaining(spanProps));
            expect(extractSpanProps(minimalProps)).toEqual(expect.not.objectContaining(spanProps));
        });
    });
});
